<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:in="http://www.composite.net/ns/transformation/input/1.0" xmlns:lang="http://www.composite.net/ns/localization/1.0" xmlns:f="http://www.composite.net/ns/function/1.0" xmlns="http://www.w3.org/1999/xhtml" exclude-result-prefixes="xsl in lang f">

	<xsl:variable name="items" select="/in:inputs/in:result[@name='GetUsStateXml']" />
	<xsl:variable name="orderBy" select="/in:inputs/in:result[@name='OrderBy']" />
	<xsl:variable name="pageId" select="/in:inputs/in:result[@name='GetPageId']" />

	<xsl:template match="/">
		<html>
			<head>
				<link rel="stylesheet" type="text/css" href="~/Frontend/Sample/Paging/UsState/Styles.css" />
			</head>
			<body>
				<div id="States" >

					<!-- Info on Pages -->
					<xsl:apply-templates select="$items/PagingInfo" mode="Navigation" />

					<!-- Info on Items -->
					<xsl:apply-templates select="$items/PagingInfo" mode="Info" />
					
					<!-- List pages -->
					<div class="PagingList">
						<xsl:apply-templates select="$items/PagingInfo" mode="PagingList" />
					</div>

					<!-- The list of the US states -->
					<table class="StateList">
						<tr>
							<th>
								<a href="~/page({$pageId})?OrderBy=Abbreviation">Abbreviation </a>
							</th>
							<th>
								<a href="~/page({$pageId})?OrderBy=Name">Name</a>
							</th>
							<th>
								<a href="~/page({$pageId})?OrderBy=Capital">Capital</a>
							</th>
						</tr>
						<xsl:for-each select="$items/UsState">
							<tr>
								<td>
									<xsl:value-of select="@Abbreviation" />
								</td>
								<td>
									<xsl:value-of select="@Name" />
								</td>
								<td>
									<xsl:value-of select="@Capital" />
								</td>
							</tr>
						</xsl:for-each>
					</table>
				</div>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="PagingInfo" mode="Navigation">
		<div class="PagingInfo">
			<xsl:choose>
				<xsl:when test="@CurrentPageNumber &gt; 1">
					<xsl:text>&lt; </xsl:text>
					<a href="~/page({$pageId})?OrderBy={$orderBy}&amp;Page={@CurrentPageNumber - 1}">Prev</a>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>&lt; Prev</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text> | Page </xsl:text>
			<xsl:value-of select="@CurrentPageNumber" />
			<xsl:text> of </xsl:text>
			<xsl:value-of select="@TotalPageCount" />
			<xsl:text> | </xsl:text>
			<xsl:choose>
				<xsl:when test="@CurrentPageNumber &lt; @TotalPageCount">
					<a href="~/page({$pageId})?OrderBy={$orderBy}&amp;Page={@CurrentPageNumber + 1}">Next</a>
					<xsl:text> &gt;</xsl:text>
				</xsl:when>
				<xsl:otherwise>Next &gt;</xsl:otherwise>
			</xsl:choose>
		</div>
	</xsl:template>

	<xsl:template match="PagingInfo" mode="Info">
		<div class="ItemInfo">
			<xsl:text>Showing Items </xsl:text>
			<xsl:value-of select="@CurrentItemNumberStart" />
			<xsl:text> to </xsl:text>
			<xsl:value-of select="@CurrentItemNumberEnd" />
			<xsl:text> of </xsl:text>
			<xsl:value-of select="@TotalItemCount" />
		</div>
	</xsl:template>

	<xsl:template match="PagingInfo" mode="PagingList">
		<xsl:param name="page" select="1"></xsl:param>
		<xsl:choose>
			<xsl:when test="@CurrentPageNumber != $page">
				<a href="~/page({$pageId})?OrderBy={$orderBy}&amp;Page={$page}">
					<xsl:value-of select="$page"/>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<span>
					<xsl:value-of select="$page"/>
				</span>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="$page &lt; @TotalPageCount">
			<xsl:apply-templates select="." mode="PagingList">
				<xsl:with-param name="page" select="$page + 1" />
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>